#include "M33.h"

V3& M33::operator[](int i) {

	return rows[i];

}

V3 M33::GetColumn(int i) {

	M33 &m = *this;
	V3 ret;
	ret[0] = m[0][i];
	ret[1] = m[1][i];
	ret[2] = m[2][i];
	return ret;

}

void M33::SetColumn(int i, V3 colv) {

	M33 &m = *this;
	m[0][i] = colv[0];
	m[1][i] = colv[1];
	m[2][i] = colv[2];

}

V3 M33::operator*(V3 v) {

	M33 &m = *this;
	V3 ret;
	ret[0] = m[0] * v;
	ret[1] = m[1] * v;
	ret[2] = m[2] * v;
	return ret;
}

M33 M33::Inverted() {

	M33 ret;
	V3 a = GetColumn(0), b = GetColumn(1), c = GetColumn(2);
	V3 _a = b ^ c; _a = _a / (a * _a);
	V3 _b = c ^ a; _b = _b / (b * _b);
	V3 _c = a ^ b; _c = _c / (c * _c);
	ret[0] = _a;
	ret[1] = _b;
	ret[2] = _c;

	return ret;

}


M33 M33::operator*(M33 m1) {

	M33 &m0 = *this;
	M33 ret;
	ret.SetColumn(0, m0*m1.GetColumn(0));
	ret.SetColumn(1, m0*m1.GetColumn(1));
	ret.SetColumn(2, m0*m1.GetColumn(2));
	return ret;
}

void M33::SetRotY(float theta) {

	M33 &m = *this;
	float thetar = theta / 180.0f * 3.14159267f;
	m[0] = V3(cosf(thetar), 0.0f, sinf(thetar));
	m[1] = V3(0.0f, 1.0f, 0.0f);
	m[2] = V3(-sinf(thetar), 0.0f, cosf(thetar));

}

M33 M33::Transposed() {

	M33 ret;
	ret[0] = GetColumn(0);
	ret[1] = GetColumn(1);
	ret[2] = GetColumn(2);
	return ret;

}
